<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="de">
<context>
    <name>MainWindow</name>
    <message>
        <location filename="../mainwindow.ui" line="20"/>
        <location filename="../mainwindow.cpp" line="89"/>
        <source>MX Package Installer</source>
        <translation>MX Paket-Installer</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="57"/>
        <source>Popular Applications</source>
        <translation>Beliebte Anwendungen</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="83"/>
        <location filename="../mainwindow.cpp" line="92"/>
        <source>Package</source>
        <translation>Paket</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="88"/>
        <location filename="../mainwindow.cpp" line="92"/>
        <source>Info</source>
        <translation>Info</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="93"/>
        <location filename="../mainwindow.ui" line="250"/>
        <location filename="../mainwindow.ui" line="660"/>
        <location filename="../mainwindow.ui" line="989"/>
        <location filename="../mainwindow.cpp" line="92"/>
        <source>Description</source>
        <translation>Beschreibung</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="113"/>
        <location filename="../mainwindow.ui" line="216"/>
        <location filename="../mainwindow.ui" line="626"/>
        <location filename="../mainwindow.ui" line="958"/>
        <location filename="../mainwindow.ui" line="1233"/>
        <source>search</source>
        <translation>Suche </translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="123"/>
        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;span style=&quot; font-size:16pt;&quot;&gt;Manage popular packages&lt;/span&gt;&lt;/p&gt;&lt;p&gt;Greyed out items have already been installed.&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;span style=&quot; font-size:16pt;&quot;&gt;Verwalten Sie beliebte Pakete&lt;/span&gt;&lt;/p&gt;&lt;p&gt;Ausgegraute Objekte wurden bereits installiert.&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="153"/>
        <source>Stable Repo</source>
        <translation>Stabiles Repository</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="174"/>
        <location filename="../mainwindow.ui" line="571"/>
        <location filename="../mainwindow.ui" line="903"/>
        <location filename="../mainwindow.ui" line="1181"/>
        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;Filter packages according to their status.&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;Pakete anhand ihres Status filtern.&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="177"/>
        <location filename="../mainwindow.ui" line="181"/>
        <location filename="../mainwindow.ui" line="574"/>
        <location filename="../mainwindow.ui" line="578"/>
        <location filename="../mainwindow.ui" line="906"/>
        <location filename="../mainwindow.ui" line="910"/>
        <location filename="../mainwindow.cpp" line="2333"/>
        <source>All packages</source>
        <translation>Alle Pakete</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="186"/>
        <location filename="../mainwindow.ui" line="583"/>
        <location filename="../mainwindow.ui" line="915"/>
        <location filename="../mainwindow.cpp" line="2347"/>
        <source>Installed</source>
        <translation>Installiert</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="191"/>
        <location filename="../mainwindow.ui" line="588"/>
        <location filename="../mainwindow.ui" line="920"/>
        <location filename="../mainwindow.cpp" line="2345"/>
        <source>Upgradable</source>
        <translation>Aktualisierbar</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="196"/>
        <location filename="../mainwindow.ui" line="593"/>
        <location filename="../mainwindow.ui" line="925"/>
        <location filename="../mainwindow.ui" line="1213"/>
        <location filename="../mainwindow.cpp" line="2312"/>
        <location filename="../mainwindow.cpp" line="2349"/>
        <location filename="../mainwindow.cpp" line="2438"/>
        <source>Not installed</source>
        <translation>Nicht installiert</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="240"/>
        <location filename="../mainwindow.ui" line="650"/>
        <location filename="../mainwindow.ui" line="979"/>
        <source>Package Name</source>
        <translation>Paketname</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="245"/>
        <location filename="../mainwindow.ui" line="655"/>
        <location filename="../mainwindow.ui" line="984"/>
        <location filename="../mainwindow.ui" line="1268"/>
        <source>Version</source>
        <translation>Version</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="277"/>
        <location filename="../mainwindow.ui" line="687"/>
        <location filename="../mainwindow.ui" line="1046"/>
        <source>Total packages:</source>
        <translation>Pakete gesamt:</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="354"/>
        <location filename="../mainwindow.ui" line="737"/>
        <location filename="../mainwindow.ui" line="1025"/>
        <source>Installed:</source>
        <translation>Installiert:</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="384"/>
        <location filename="../mainwindow.ui" line="767"/>
        <location filename="../mainwindow.ui" line="1018"/>
        <source>Upgradable:</source>
        <translation>Aktualisierbar:</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="291"/>
        <location filename="../mainwindow.ui" line="1338"/>
        <source>Upgrade All</source>
        <translation>Alle aktualisieren</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="318"/>
        <location filename="../mainwindow.ui" line="701"/>
        <location filename="../mainwindow.ui" line="1053"/>
        <source>Hide library and developer packages</source>
        <translation>Bibliotheken und Entwicklerpakete verstecken</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="340"/>
        <location filename="../mainwindow.ui" line="723"/>
        <location filename="../mainwindow.ui" line="1105"/>
        <source>Refresh list</source>
        <translation>Liste aktualisieren</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="414"/>
        <location filename="../mainwindow.ui" line="794"/>
        <location filename="../mainwindow.ui" line="1086"/>
        <source>Also Install &quot;Recommended&quot; Packages</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="424"/>
        <location filename="../mainwindow.ui" line="601"/>
        <location filename="../mainwindow.ui" line="933"/>
        <location filename="../mainwindow.ui" line="1481"/>
        <source>Greyed out items have already been installed.</source>
        <translation>Die ausgegrauten Einträge sind Pakete, die bereits installiert wurden.</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="480"/>
        <location filename="../mainwindow.ui" line="543"/>
        <location filename="../mainwindow.ui" line="870"/>
        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;= Upgradable package. Newer version available in selected repository.&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;= Aktualisierbares Paket. Neuere Version im gewählten Repositorium verfügbar.&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="500"/>
        <source>MX Test Repo</source>
        <translation>MX Test Repositorium</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="827"/>
        <source>Debian Backports</source>
        <translation>Debian Backports</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1160"/>
        <source>Flatpaks</source>
        <translation>Flatpaks</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1184"/>
        <location filename="../mainwindow.ui" line="1188"/>
        <location filename="../mainwindow.cpp" line="2293"/>
        <source>All apps</source>
        <translation>Alle Apps</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1193"/>
        <location filename="../mainwindow.cpp" line="2298"/>
        <source>All runtimes</source>
        <translation>Alle Runtimes</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1198"/>
        <location filename="../mainwindow.cpp" line="2303"/>
        <source>All available</source>
        <translation>Alle verfügbaren</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1203"/>
        <location filename="../mainwindow.cpp" line="2291"/>
        <location filename="../mainwindow.cpp" line="2433"/>
        <source>Installed apps</source>
        <translation>Installierte Apps</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1208"/>
        <location filename="../mainwindow.cpp" line="2289"/>
        <source>Installed runtimes</source>
        <translation>Installierte Runtimes</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1258"/>
        <source>Short Name</source>
        <translation>Kurzname</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1263"/>
        <source>Full Package Name</source>
        <translation>Völlständiger Paketname</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1273"/>
        <source>Size</source>
        <translation>Größe</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1317"/>
        <source>Total items </source>
        <translation>Gesamtanzahl</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1331"/>
        <source>Installed apps:</source>
        <translation>Installierte Apps:</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1384"/>
        <source>Advanced</source>
        <translation>Fortgeschritten</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1414"/>
        <source>Total installed size:</source>
        <translation>Gesamte Installationsgröße:</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1431"/>
        <location filename="../mainwindow.ui" line="1435"/>
        <source>For all users</source>
        <translation>Für alle Benutzer</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1440"/>
        <source>For current user</source>
        <translation>Für aktuellen Benutzer</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1458"/>
        <source>Remote (repo):</source>
        <translation>Flatpak-Repository:</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1501"/>
        <location filename="../mainwindow.cpp" line="2120"/>
        <location filename="../mainwindow.cpp" line="2246"/>
        <source>Console Output</source>
        <translation>Konsolenausgabe</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1507"/>
        <source>Enter</source>
        <translation>Enter</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1518"/>
        <source>Respond here, or just press Enter</source>
        <translation>Hier antworten oder nur Enter drücken.</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1574"/>
        <source>Uninstall</source>
        <translation>Deinstallieren</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1581"/>
        <source>Alt+U</source>
        <translation>Alt+U</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1597"/>
        <source>About this application</source>
        <translation>Über dieses Programm</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1600"/>
        <source>About...</source>
        <translation>Über...</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1607"/>
        <source>Alt+B</source>
        <translation>Alt+B</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1655"/>
        <source>Display help </source>
        <translation>Hilfe anzeigen</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1658"/>
        <source>Help</source>
        <translation>Hilfe</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1665"/>
        <source>Alt+H</source>
        <translation>Alt+H</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1681"/>
        <location filename="../mainwindow.cpp" line="1008"/>
        <location filename="../mainwindow.cpp" line="2007"/>
        <location filename="../mainwindow.cpp" line="2427"/>
        <location filename="../mainwindow.cpp" line="2430"/>
        <source>Install</source>
        <translation>Installieren</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1688"/>
        <source>Alt+I</source>
        <translation>Alt+I</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1707"/>
        <source>Quit application</source>
        <translation>Anwendung beenden</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1710"/>
        <source>Close</source>
        <translation>Schließen</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1717"/>
        <source>Alt+C</source>
        <translation>Alt+C</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="159"/>
        <source>Uninstalling packages...</source>
        <translation>Deinstalliere Pakete...</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="164"/>
        <source>Running pre-uninstall operations...</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="177"/>
        <source>Running post-uninstall operations...</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="196"/>
        <source>Refreshing sources...</source>
        <translation>Quellen werden neu eingelesen....</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="209"/>
        <location filename="../mainwindow.cpp" line="1042"/>
        <location filename="../mainwindow.cpp" line="1168"/>
        <location filename="../mainwindow.cpp" line="1291"/>
        <location filename="../mainwindow.cpp" line="1910"/>
        <location filename="../mainwindow.cpp" line="1937"/>
        <location filename="../mainwindow.cpp" line="1947"/>
        <location filename="../mainwindow.cpp" line="2091"/>
        <location filename="../mainwindow.cpp" line="2111"/>
        <location filename="../mainwindow.cpp" line="2517"/>
        <location filename="../mainwindow.cpp" line="2593"/>
        <location filename="../mainwindow.cpp" line="2620"/>
        <source>Error</source>
        <translation>Fehler</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="209"/>
        <source>There was a problem updating sources. Some sources may not have provided updates. For more info check: </source>
        <translation>Ein Problem ist beim Aktualisieren der Quellen aufgetreten. Einige Quellen könnten nicht aktualisiert worden sein. Für mehr Informationen siehe:</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="567"/>
        <source>Cancel</source>
        <translation>Abbruch</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="573"/>
        <source>Please wait...</source>
        <translation>Bitte warten...</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="770"/>
        <location filename="../mainwindow.cpp" line="788"/>
        <source>Version </source>
        <translation>Version</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="770"/>
        <source> in stable repo</source>
        <translation>im Repositorium Stable </translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="772"/>
        <source>Not available in stable repo</source>
        <translation>Nicht verfügbar im Repositorium Stable</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="782"/>
        <location filename="../mainwindow.cpp" line="2226"/>
        <source>Latest version </source>
        <translation>Neueste Version</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="782"/>
        <location filename="../mainwindow.cpp" line="2226"/>
        <source> already installed</source>
        <translation>bereits schon installiert</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="788"/>
        <source> installed</source>
        <translation>installiert</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="900"/>
        <source>You are about to use the MX Test repository, whose packages are provided for testing purposes only. It is possible that they might break your system, so it is suggested that you back up your system and install or update only one package at a time. Please provide feedback in the Forum so the package can be evaluated before moving up to Main.</source>
        <translation>Sie sind im Begriff, das MX Testrepo zunutzen, dessen Pakete nur zu Testzwecken zur Verfügung gestellt werden. Es ist möglich, daß diese Pakete das System unbrauchbar machenkönnen; deshalb wird empfohlen, eine Sicherung des Systems anzulegen und immer nur einzelne Pakete zu installieren oder aktualisieren. Bitte geben Sie auch Rückmeldungen im Forum ab, damit das jeweilige Paket evaluiert werden kann bevor es in die stabile Version übernommen wird.</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="909"/>
        <source>You are about to use Debian Backports, which contains packages taken from the next Debian release (called &apos;testing&apos;), adjusted and recompiled for usage on Debian stable. They cannot be tested as extensively as in the stable releases of Debian and MX Linux, and are provided on an as-is basis, with risk of incompatibilities with other components in Debian stable. Use with care!</source>
        <translation>Sie sind dabei Debian Backports zu benutzen, welches Pakete aus der nächsten Debian Freigabe (&quot;testing&quot;) enthält, die zur Nutzung in Debian Stable angepasst und neu kompiliert wurden. Diese Pakete konnten nicht so intensiv wie in der stabilen Freigabe von Debian und MX Linux getestet werden und werden ohne Garantie und mit dem Risiko der Inkompatibilität zu Komponenten aus Debian Stable zur Verfügung gestellt. Mit Vorsicht verwenden! </translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="917"/>
        <source>MX Linux includes this repository of flatpaks for the users&apos; convenience only, and is not responsible for the functionality of the individual flatpaks themselves. For more, consult flatpaks in the Wiki.</source>
        <translation>MX Linux enthält dieses Repo von Flatpaks nur aus Gründen der Benutzerfreundlichkeit und ist nicht verantwortlich für die Funktionalität der einzelnen Flatpaks. Nähere Infos dazu stehen im Wiki.</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="926"/>
        <source>Warning</source>
        <translation>Warnung</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="930"/>
        <source>Do not show this message again</source>
        <translation>Diese Meldung nicht mehr anzeigen</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="1005"/>
        <source>Remove</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="1019"/>
        <source>The following packages were selected. Click Show Details for list of changes.</source>
        <translation>Die folgenden Pakete wurden ausgewählt. Klicken Sie auf Details anzeigen, um eine Liste der Änderungen anzuzeigen.</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="1042"/>
        <location filename="../mainwindow.cpp" line="1168"/>
        <location filename="../mainwindow.cpp" line="1291"/>
        <source>Internet is not available, won&apos;t be able to download the list of packages</source>
        <translation>Internet ist nicht verfügbar. Die  Paketeliste kann nicht heruntergeladen werden.</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="1047"/>
        <source>Installing packages...</source>
        <translation>Installiere Pakete...</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="1098"/>
        <source>Post-processing...</source>
        <translation>Nachbearbeitung...</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="1130"/>
        <source>Pre-processing for </source>
        <translation>Vorverarbeitung für</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="1143"/>
        <source>Installing </source>
        <translation>Installiere</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="1150"/>
        <source>Post-processing for </source>
        <translation>Nachbearbeitung für</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="1298"/>
        <source>Downloading package info...</source>
        <translation>Lade Paketinformationen herunter...</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="1750"/>
        <source>Packages to be installed: </source>
        <translation>Zu installierende Pakete:</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="1788"/>
        <source>Package info</source>
        <translation>Paketinformationen</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="1906"/>
        <location filename="../mainwindow.cpp" line="1918"/>
        <location filename="../mainwindow.cpp" line="1931"/>
        <location filename="../mainwindow.cpp" line="1944"/>
        <location filename="../mainwindow.cpp" line="2064"/>
        <location filename="../mainwindow.cpp" line="2086"/>
        <location filename="../mainwindow.cpp" line="2513"/>
        <location filename="../mainwindow.cpp" line="2587"/>
        <location filename="../mainwindow.cpp" line="2614"/>
        <source>Done</source>
        <translation>Erledigt</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="1906"/>
        <location filename="../mainwindow.cpp" line="1918"/>
        <location filename="../mainwindow.cpp" line="1931"/>
        <location filename="../mainwindow.cpp" line="1944"/>
        <location filename="../mainwindow.cpp" line="2064"/>
        <location filename="../mainwindow.cpp" line="2086"/>
        <location filename="../mainwindow.cpp" line="2104"/>
        <location filename="../mainwindow.cpp" line="2513"/>
        <location filename="../mainwindow.cpp" line="2587"/>
        <location filename="../mainwindow.cpp" line="2614"/>
        <source>Processing finished successfully.</source>
        <translation>Verarbeitung erfolgreich beendet</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="1910"/>
        <location filename="../mainwindow.cpp" line="1937"/>
        <location filename="../mainwindow.cpp" line="1947"/>
        <location filename="../mainwindow.cpp" line="2517"/>
        <location filename="../mainwindow.cpp" line="2593"/>
        <location filename="../mainwindow.cpp" line="2620"/>
        <source>Problem detected while installing, please inspect the console output.</source>
        <translation>Bei der Installation trat ein Problem auf; siehe Konsolenausgabe </translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="1957"/>
        <source>About %1</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="1962"/>
        <source>%1 License</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="1976"/>
        <source>%1 Help</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>About MX Package Installer</source>
        <translation type="vanished">Über MX Paket-Installer</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="1958"/>
        <source>Version: </source>
        <translation>Version:</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="1959"/>
        <source>Package Installer for MX Linux</source>
        <translation>Paket-Installation für MX Linux</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="1961"/>
        <source>Copyright (c) MX Linux</source>
        <translation>Copyright (c) MX Linux</translation>
    </message>
    <message>
        <source>License</source>
        <translation type="vanished">Lizenz</translation>
    </message>
    <message>
        <source>Changelog</source>
        <translation type="vanished">Changelog</translation>
    </message>
    <message>
        <source>&amp;Close</source>
        <translation type="vanished">&amp;Close</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="2005"/>
        <source>Reinstall</source>
        <translation>Erneut installieren</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="2091"/>
        <source>We encountered a problem uninstalling, please check output</source>
        <translation>Es gab ein Problem beim Deinstallieren. Bitte die Ausgabe überprüfen.</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="2104"/>
        <source>Success</source>
        <translation>Erfolg</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="2111"/>
        <source>We encountered a problem uninstalling the program</source>
        <translation>Beim Deinstallieren des Programms trat ein Problem auf</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="2202"/>
        <location filename="../mainwindow.cpp" line="2213"/>
        <source>Flatpak not installed</source>
        <translation>Flatpak nicht installiert</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="2202"/>
        <source>Flatpak is not currently installed.
OK to go ahead and install it?</source>
        <translation>Flatpak ist nocht nickt installiert.
Mit OK die Installation bestätigen?</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="2213"/>
        <source>Flatpak was not installed</source>
        <translation>Flatpak wurde nicht installiert</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="2234"/>
        <location filename="../mainwindow.cpp" line="2253"/>
        <source>Flathub remote failed</source>
        <translation>Flathub repo fehlgeschlagen</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="2234"/>
        <location filename="../mainwindow.cpp" line="2253"/>
        <source>Flathub remote could not be added</source>
        <translation>Flathub Repository konnte nicht hinzugefügt werden</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="2242"/>
        <source>Needs re-login</source>
        <translation>Re-login erforderlich</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="2242"/>
        <source>You might need to logout/login to see installed items in the menu</source>
        <translation>Erst nach dem Ab- und wieder Anmelden werden installierte Anwendungen im Menu sichtbar.</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="2425"/>
        <source>Upgrade</source>
        <translation>Aktualisieren</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="2547"/>
        <source>Quit?</source>
        <translation>Beenden? </translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="2548"/>
        <source>Process still running, quitting might leave the system in an unstable state.&lt;p&gt;&lt;b&gt;Are you sure you want to exit MX Package Installer?&lt;/b&gt;</source>
        <translation>Der Prozeß läuft noch. Ein Abbrechen könnte das System in einen instabilen Zustand bringen.&lt;p&gt;&lt;b&gt;Sind Sie sicher, MX Package Installer zu beenden?&lt;/b&gt;</translation>
    </message>
</context>
<context>
    <name>ManageRemotes</name>
    <message>
        <location filename="../remotes.cpp" line="14"/>
        <source>Manage Flatpak Remotes</source>
        <translation>Verwalten von Flatpak Repositorien.</translation>
    </message>
    <message>
        <location filename="../remotes.cpp" line="23"/>
        <source>For all users</source>
        <translation>Für alle Benutzer</translation>
    </message>
    <message>
        <location filename="../remotes.cpp" line="24"/>
        <source>For current user</source>
        <translation>Für aktuellen Benutzer</translation>
    </message>
    <message>
        <location filename="../remotes.cpp" line="30"/>
        <source>enter Flatpak remote URL</source>
        <translation>Flatpak Repository URL eingeben</translation>
    </message>
    <message>
        <location filename="../remotes.cpp" line="33"/>
        <source>enter Flatpakref location to install app</source>
        <translation>Flatpakref Pfad/URL zur Installation eingeben</translation>
    </message>
    <message>
        <location filename="../remotes.cpp" line="35"/>
        <source>Add or remove flatpak remotes (repos), or install apps using flatpakref URL or path</source>
        <translation>Hinzufügen und Entfernen von Flatpak Repos, oder Installation von Flatpak-Apps mit Flatpakref (Pfad/URL)</translation>
    </message>
    <message>
        <location filename="../remotes.cpp" line="44"/>
        <source>Remove remote</source>
        <translation>Entfernen des Flatpak-Repos</translation>
    </message>
    <message>
        <location filename="../remotes.cpp" line="49"/>
        <source>Add remote</source>
        <translation>Hinzufügen des Flatpak-Repos</translation>
    </message>
    <message>
        <location filename="../remotes.cpp" line="54"/>
        <source>Install app</source>
        <translation>Anwendung installieren</translation>
    </message>
    <message>
        <location filename="../remotes.cpp" line="59"/>
        <source>Close</source>
        <translation>Schließen</translation>
    </message>
    <message>
        <location filename="../remotes.cpp" line="76"/>
        <source>Not removable</source>
        <translation>Nicht entfernbar</translation>
    </message>
    <message>
        <location filename="../remotes.cpp" line="76"/>
        <source>Flathub is the main Flatpak remote and won&apos;t be removed</source>
        <translation>Flathub ist das Flatpak Haupt-Repositorium und kann nicht entfernt werden</translation>
    </message>
    <message>
        <location filename="../remotes.cpp" line="92"/>
        <source>Error adding remote</source>
        <translation>Fehler beim Hinzufügen des Repos</translation>
    </message>
    <message>
        <location filename="../remotes.cpp" line="92"/>
        <source>Could not add remote - command returned an error. Please double-check the remote address and try again</source>
        <translation>Konnte das Repository nicht hinzufügen - der Befehl endete mit einem Fehler. Bitte die Repository-URL überprüfen und nochmal versuchen.</translation>
    </message>
    <message>
        <location filename="../remotes.cpp" line="96"/>
        <source>Success</source>
        <translation>Erfolg</translation>
    </message>
    <message>
        <location filename="../remotes.cpp" line="96"/>
        <source>Remote added successfully</source>
        <translation>Flatpak Repository erfolgreich hinzugefügt.</translation>
    </message>
</context>
<context>
    <name>QApplication</name>
    <message>
        <source>Unable to get exclusive lock</source>
        <translation type="vanished">Exklusivsperre nicht möglich</translation>
    </message>
    <message>
        <source>Another package management application (like Synaptic or apt-get), is already running. Please close that application first</source>
        <translation type="vanished">Eine andere Paketmanager Anwendung (evtl. Synaptic oder apt-get) läuft bereits. Bitte diese Anwendung erst beenden.</translation>
    </message>
    <message>
        <source>You must run this program as root.</source>
        <translation type="vanished">Dieses Programm muss als root ausgeführt werden</translation>
    </message>
    <message>
        <source>License</source>
        <translation type="obsolete">Lizenz</translation>
    </message>
    <message>
        <source>Changelog</source>
        <translation type="obsolete">Changelog</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation type="obsolete">Abbruch</translation>
    </message>
    <message>
        <source>&amp;Close</source>
        <translation type="obsolete">&amp;Close</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <location filename="../about.cpp" line="32"/>
        <source>License</source>
        <translation type="unfinished">Lizenz</translation>
    </message>
    <message>
        <location filename="../about.cpp" line="33"/>
        <location filename="../about.cpp" line="43"/>
        <source>Changelog</source>
        <translation type="unfinished">Changelog</translation>
    </message>
    <message>
        <location filename="../about.cpp" line="34"/>
        <source>Cancel</source>
        <translation type="unfinished">Abbruch</translation>
    </message>
    <message>
        <location filename="../about.cpp" line="51"/>
        <source>&amp;Close</source>
        <translation type="unfinished">&amp;Close</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="66"/>
        <source>Unable to get exclusive lock</source>
        <translation type="unfinished">Exklusivsperre nicht möglich</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="67"/>
        <source>Another package management application (like Synaptic or apt-get), is already running. Please close that application first</source>
        <translation type="unfinished">Eine andere Paketmanager Anwendung (evtl. Synaptic oder apt-get) läuft bereits. Bitte diese Anwendung erst beenden.</translation>
    </message>
</context>
</TS>
